[Bf-blender-cvs] [1418eee5f5c] master: macOS: increase minimum required version to 10.11

Brecht Van Lommel noreply at git.blender.org
Sun Jun 2 13:07:11 CEST 2019


Commit: 1418eee5f5c84d3ec24d326952e57e248e27ef96
Author: Brecht Van Lommel
Date:   Sat Jun 1 17:49:26 2019 +0200
Branches: master
https://developer.blender.org/rB1418eee5f5c84d3ec24d326952e57e248e27ef96

macOS: increase minimum required version to 10.11

This is in preparation of an the upcoming fix where we need to use a Metal
layer to avoid performance issue when drawing with OpenGL. Note that we already
only officially support 10.12+, the difference with this change is that Blender
will not start at all on 10.9 and 10.10.

===================================================================

M	build_files/build_environment/cmake/options.cmake
M	build_files/cmake/platform/platform_apple.cmake
M	build_files/cmake/platform/platform_apple_xcode.cmake

===================================================================

diff --git a/build_files/build_environment/cmake/options.cmake b/build_files/build_environment/cmake/options.cmake
index d7acf25ba58..ded13977c05 100644
--- a/build_files/build_environment/cmake/options.cmake
+++ b/build_files/build_environment/cmake/options.cmake
@@ -126,13 +126,13 @@ else()
       OUTPUT_VARIABLE XCODE_DEV_PATH OUTPUT_STRIP_TRAILING_WHITESPACE
     )
     set(OSX_ARCHITECTURES x86_64)
-    set(OSX_DEPLOYMENT_TARGET 10.9)
+    set(OSX_DEPLOYMENT_TARGET 10.11)
     set(OSX_SYSROOT ${XCODE_DEV_PATH}/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk)
 
     set(PLATFORM_CFLAGS "-isysroot ${OSX_SYSROOT} -mmacosx-version-min=${OSX_DEPLOYMENT_TARGET}")
     set(PLATFORM_CXXFLAGS "-isysroot ${OSX_SYSROOT} -mmacosx-version-min=${OSX_DEPLOYMENT_TARGET} -std=c++11 -stdlib=libc++")
     set(PLATFORM_LDFLAGS "-isysroot ${OSX_SYSROOT} -mmacosx-version-min=${OSX_DEPLOYMENT_TARGET}")
-    set(PLATFORM_BUILD_TARGET --build=x86_64-apple-darwin13.0.0) # OS X 10.9
+    set(PLATFORM_BUILD_TARGET --build=x86_64-apple-darwin15.0.0) # OS X 10.11
     set(PLATFORM_CMAKE_FLAGS
       -DCMAKE_OSX_ARCHITECTURES:STRING=${OSX_ARCHITECTURES}
       -DCMAKE_OSX_DEPLOYMENT_TARGET:STRING=${OSX_DEPLOYMENT_TARGET}
diff --git a/build_files/cmake/platform/platform_apple.cmake b/build_files/cmake/platform/platform_apple.cmake
index 3fd07f5b9c5..3366d49868d 100644
--- a/build_files/cmake/platform/platform_apple.cmake
+++ b/build_files/cmake/platform/platform_apple.cmake
@@ -20,7 +20,7 @@
 
 # Libraries configuration for Apple.
 
-set(MACOSX_DEPLOYMENT_TARGET "10.9")
+set(MACOSX_DEPLOYMENT_TARGET "10.11")
 
 macro(find_package_wrapper)
 # do nothing, just satisfy the macro
diff --git a/build_files/cmake/platform/platform_apple_xcode.cmake b/build_files/cmake/platform/platform_apple_xcode.cmake
index 81bd6f906de..b7d43792056 100644
--- a/build_files/cmake/platform/platform_apple_xcode.cmake
+++ b/build_files/cmake/platform/platform_apple_xcode.cmake
@@ -93,19 +93,14 @@ else()
   endif()
 endif()
 
-if(OSX_SYSTEM MATCHES 10.9)
-  # make sure syslibs and headers are looked up in sdk ( especially for 10.9 openGL atm. )
-  set(CMAKE_FIND_ROOT_PATH ${CMAKE_OSX_SYSROOT})
-endif()
-
-# 10.9 is our min. target, if you use higher sdk, weak linking happens
+# 10.11 is our min. target, if you use higher sdk, weak linking happens
 if(CMAKE_OSX_DEPLOYMENT_TARGET)
-  if(${CMAKE_OSX_DEPLOYMENT_TARGET} VERSION_LESS 10.9)
-    message(STATUS "Setting deployment target to 10.9, lower versions are not supported")
-    set(CMAKE_OSX_DEPLOYMENT_TARGET "10.9" CACHE STRING "" FORCE)
+  if(${CMAKE_OSX_DEPLOYMENT_TARGET} VERSION_LESS 10.11)
+    message(STATUS "Setting deployment target to 10.11, lower versions are not supported")
+    set(CMAKE_OSX_DEPLOYMENT_TARGET "10.11" CACHE STRING "" FORCE)
   endif()
 else()
-  set(CMAKE_OSX_DEPLOYMENT_TARGET "10.9" CACHE STRING "" FORCE)
+  set(CMAKE_OSX_DEPLOYMENT_TARGET "10.11" CACHE STRING "" FORCE)
 endif()
 
 if(NOT ${CMAKE_GENERATOR} MATCHES "Xcode")



More information about the Bf-blender-cvs mailing list